@@ -6,5 +6,5 @@ from kii.app import core
 urlpatterns = patterns('',
     (r'^admin/', include(admin.site.urls)),
     url(r'^accounts/', include('django.contrib.auth.urls')),    
-    url(r'^kii/', include("kii.urls", namespace="kii")),
+    url(r'^kii/', include("kii.urls")),
 )
