@@ -31,4 +31,7 @@ class UserTestCase(base.BaseTestCase):
         return self.client.get(settings.LOGOUT_URL)
 
     def tearDown(self):
-        self.logout()
\ No newline at end of file
+        self.logout()
+
+    def assertRedirectsLogin(self, response, next):
+        self.assertRedirects(response, reverse(settings.LOGIN_URL)+"?next="+next)
\ No newline at end of file
